@@ -1,4 +1,15 @@
 from mokaccino import Query
+import pytest
+
+def test_query_parsing():
+    q = Query.parse("name:sausage")
+    assert q is not None
+    assert "name=sausage" in str(q)
+    with pytest.raises(RuntimeError):
+        Query.parse("invalid query string")
+    # See other examples of query parsing at
+    # https://crates.io/crates/mokaccino
+
 
 def test_final_queries():
     assert Query.from_kv("field", "value") is not None
